==> nova-30.2.1.tar.gz: nova-30.2.1/nova/api/openstack/compute/fixed_ips.py <==
# Copyright 2012 IBM Corp.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from webob import exc

from nova.api.openstack.compute.schemas import fixed_ips as schema_fixed_ips
from nova.api.openstack import wsgi
from nova.api import validation

_removal_reason = """\
This API only works with *nova-network*, which was deprecated in the
14.0.0 (Newton) release.
It fails with HTTP 404 starting from microversion 2.36.
It was removed in the 18.0.0 (Rocky) release.
"""


class FixedIPController(wsgi.Controller):

    @wsgi.expected_errors((410))
    @wsgi.removed('18.0.0', _removal_reason)
    @validation.query_schema(schema_fixed_ips.show_query)
    def show(self, req, id):
        raise exc.HTTPGone()

    @wsgi.expected_errors((410))
    @wsgi.action('reserve')
    @wsgi.removed('18.0.0', _removal_reason)
    @validation.schema(schema_fixed_ips.reserve)
    def reserve(self, req, id, body):
        raise exc.HTTPGone()

    @wsgi.expected_errors((410))
    @wsgi.action('unreserve')
    @wsgi.removed('18.0.0', _removal_reason)
    @validation.schema(schema_fixed_ips.unreserve)
    def unreserve(self, req, id, body):
        raise exc.HTTPGone()

==> nova_31.0.0.orig.tar.gz: nova-31.0.0/nova/api/openstack/compute/fixed_ips.py <==
# Copyright 2012 IBM Corp.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from webob import exc

from nova.api.openstack.compute.schemas import fixed_ips as schema
from nova.api.openstack import wsgi
from nova.api import validation

_removal_reason = """\
This API only works with *nova-network*, which was deprecated in the
14.0.0 (Newton) release.
It fails with HTTP 404 starting from microversion 2.36.
It was removed in the 18.0.0 (Rocky) release.
"""


class FixedIPController(wsgi.Controller):

    @wsgi.expected_errors((410))
    @wsgi.removed('18.0.0', _removal_reason)
    @validation.query_schema(schema.show_query)
    def show(self, req, id):
        raise exc.HTTPGone()

    @wsgi.expected_errors((410))
    @wsgi.action('reserve')
    @wsgi.removed('18.0.0', _removal_reason)
    @validation.schema(schema.reserve)
    def reserve(self, req, id, body):
        raise exc.HTTPGone()

    @wsgi.expected_errors((410))
    @wsgi.action('unreserve')
    @wsgi.removed('18.0.0', _removal_reason)
    @validation.schema(schema.unreserve)
    def unreserve(self, req, id, body):
        raise exc.HTTPGone()
